@@ -1,9 +1,16 @@
+"""
+Directed grid search: Monochromatic source
+==========================================
+
+Search for a monochromatic (no spindown) signal using
+a parameter space grid (i.e. no MCMC).
+"""
 import pyfstat
 import numpy as np
 import matplotlib.pyplot as plt
 import os
 
-label = os.path.splitext(os.path.basename(__file__))[0]
+label = "PyFstat_example_grid_search_F0"
 outdir = os.path.join("PyFstat_example_data", label)
 
 F0 = 30.0
@@ -25,8 +32,6 @@ duration = 100 * 86400
 tend = tstart + duration
 tref = 0.5 * (tstart + tend)
 
-example_name = os.path.splitext(os.path.basename(__file__))[0]
-
 data = pyfstat.Writer(
     label=label,
     outdir=outdir,
@@ -54,7 +59,7 @@ F2s = [F2]
 Alphas = [Alpha]
 Deltas = [Delta]
 search = pyfstat.GridSearch(
-    example_name,
+    label,
     outdir,
     os.path.join(outdir, "*" + label + "*sft"),
     F0s,
@@ -65,15 +70,13 @@ search = pyfstat.GridSearch(
     tref,
     tstart,
     tend,
-    BSGL=False,
 )
 search.run()
 
+print("Plotting 2F(F0)...")
 fig, ax = plt.subplots()
-xidx = search.keys.index("F0")
-frequencies = np.unique(search.data[:, xidx])
-twoF = search.data[:, -1]
-
+frequencies = search.data["F0"]
+twoF = search.data["twoF"]
 # mismatch = np.sign(x-F0)*(duration * np.pi * (x - F0))**2 / 12.0
 ax.plot(frequencies, twoF, "k", lw=1)
 DeltaF = frequencies - F0
